@@ -23,7 +23,10 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
 
     # Act
     mapper = AutoMapper(
-        view="members", source_view="patients", keys=["member_id"]
+        view="members",
+        source_view="patients",
+        keys=["member_id"],
+        drop_key_columns=False
     ).columns(dst2=AutoMapperList(["address1"]))
 
     assert isinstance(mapper, AutoMapper)
